<?php

namespace Pinpoint\BannerManager\Block;

use Magento\Framework\View\Element\Template;

/**
 * Class Renderer
 * @package Pinpoint\BannerManager\Block
 */
class Renderer extends Template
{
    /**
     * @var string $_template
     */
    protected $_template = "Pinpoint_BannerManager::renderer.phtml";

    /**
     * @var \Pinpoint\BannerManager\Model\Banner
     */
    protected $banner;

    /**
     * @var \Magento\Framework\DataObject[]
     */
    protected $bannerBlocks;

    /**
     * Renderer constructor.
     * @param Template\Context $context
     * @param \Pinpoint\BannerManager\Model\Banner $banner
     * @param \Pinpoint\BannerManager\Model\BannerBlock $bannerBlocks
     * @param array $data
     */
    public function __construct(
        Template\Context $context,
        \Pinpoint\BannerManager\Model\Banner $banner,
        \Pinpoint\BannerManager\Model\BannerBlock $bannerBlocks,
        array $data = []
    ) {
        parent::__construct($context, $data);

        $this->banner = $banner->load($this->getData('banner_id'));
        $this->bannerBlocks = $bannerBlocks->getCollection()
            ->addFieldToFilter('banner_id', $this->banner->getId())->getItems();
    }

    /**
     * @return string
     */
    public function getBannerCssClass()
    {
        return str_replace(" ", "-", strtolower($this->getBanner()->getData('banner_name')));
    }

    /**
     * @return \Pinpoint\BannerManager\Model\Banner
     */
    public function getBanner()
    {
        return $this->banner;
    }

    /**
     * @return \Magento\Framework\DataObject[]
     */
    public function getBannerBlocks()
    {
        return $this->bannerBlocks;
    }

    /**
     * @param $blockId
     * @return null|int
     */
    public function getBlockWidth($blockId)
    {
        $layout = json_decode($this->getBanner()->getData('banner_content'), true);

        foreach ($layout as $blockLayout) {
            if ($blockLayout['id'] == $blockId) {
                return $blockLayout['width'];
            }
        }

        return null;
    }

    /**
     * @param $blockId
     * @return null|int
     */
    public function getBlockHeight($blockId)
    {
        $layout = json_decode($this->getBanner()->getData('banner_content'), true);

        foreach ($layout as $blockLayout) {
            if ($blockLayout['id'] == $blockId) {
                return $blockLayout['height'];
            }
        }

        return null;
    }

    /**
     * @param $blockId
     * @return null|int
     */
    public function getBlockX($blockId)
    {
        $layout = json_decode($this->getBanner()->getData('banner_content'), true);

        foreach ($layout as $blockLayout) {
            if ($blockLayout['id'] == $blockId) {
                return (int) $blockLayout['x'] + 1;
            }
        }

        return null;
    }

    /**
     * @param $blockId
     * @return null|int
     */
    public function getBlockY($blockId)
    {
        $layout = json_decode($this->getBanner()->getData('banner_content'), true);

        foreach ($layout as $blockLayout) {
            if ($blockLayout['id'] == $blockId) {
                return (int) $blockLayout['y'] + 1;
            }
        }

        return null;
    }
}
